@@ -2,11 +2,13 @@
 from . import cloud_wanderer_resource, storage_connectors
 from .aws_interface import CloudWandererAWSInterface
 from .cloud_wanderer import CloudWanderer
+from .cloud_wanderer_resource import CloudWandererResource
 from .urn import URN
 
 __all__ = [
     "storage_connectors",
     "cloud_wanderer_resource",
+    "CloudWandererResource",
     "CloudWanderer",
     "URN",
     "CloudWandererAWSInterface",
